import {
  Controller,
  Get,
  HttpException,
  HttpStatus,
  Query,
  Redirect,
  Req,
  UseGuards,
} from '@nestjs/common';
import { ApiQuery } from '@nestjs/swagger';
import { ConfigService } from '@nestjs/config';
import { AuthService } from './auth.service';
import { JwtGuard } from './guards/jwt.guard';
import { UserDto } from './dto/user.dto';
import { Request } from 'express';

@Controller('auth')
export class AuthController {
  constructor(
    private config: ConfigService,
    private authService: AuthService,
  ) {}

  @Get('/vatsim')
  @ApiQuery({
    name: 'code',
    description: 'The authorization code',
    type: String,
  })
  @Redirect()
  async vatsim(@Query('code') code) {
    if (!code) {
      throw new HttpException(
        'Code not found in the query',
        HttpStatus.NOT_ACCEPTABLE,
      );
    }

    const token = await this.authService.login(code);

    if (token !== undefined) {
      return {
        url: `${this.config.get<string>(
          'frontend.base-url',
        )}/${this.config.get<string>(
          'frontend.login-endpoint',
        )}?token=${token}`,
      };
    } else {
      return {
        url: `${this.config.get<string>(
          'frontend.base-url',
        )}/${this.config.get<string>('frontend.login-endpoint')}`,
      };
    }
  }

  @UseGuards(JwtGuard)
  @Get('/user')
  async user(@Req() request: Request): Promise<UserDto> {
    const token = request.headers.authorization.replace('Bearer ', '');
    return this.authService.user(token).then((user) => {
      if (!user) {
        throw new HttpException('Invalid user request', HttpStatus.NOT_FOUND);
      }

      return {
        vatsimId: user.vatsimId,
        fullName: user.fullName,
        administrator: user.administrator,
        airportConfigurationAccess: user.airportConfigurationAccess,
      };
    });
  }
}
