import { IsNotEmpty, IsOptional, Length } from 'class-validator';
import { ApiProperty } from '@nestjs/swagger';
import { AircraftDto } from './aircraft.dto';
import { ControllerInputDto } from './controllerinput.dto';
import { FlightStateDto } from './flightstate.dto';
import { PlanningDto } from './planning.dto';

export class InboundDto {
  @IsNotEmpty()
  @ApiProperty({
    description: 'The used callsign',
    example: 'DLH3PM',
  })
  callsign: string;

  @IsNotEmpty()
  @ApiProperty({
    description: 'The filed destination',
    example: 'EDDB',
  })
  @Length(4)
  destination: string;

  @IsNotEmpty()
  @ApiProperty({
    description:
      'The reported controller level (possible: UNK, DEL, GND, TWR, APP, DEP, CTR)',
    example: 'EDDB',
  })
  @Length(3)
  reporter: string;

  @IsNotEmpty()
  @ApiProperty({
    description: 'The used aircraft',
  })
  aircraft: AircraftDto;

  @IsNotEmpty()
  @ApiProperty({
    description: 'The current flight state',
  })
  flightState: FlightStateDto;

  @IsOptional()
  @ApiProperty({
    description: 'The data given by the controller',
  })
  controllerData: ControllerInputDto;

  @IsOptional()
  @ApiProperty({
    description: 'The planned arrival',
  })
  plan: PlanningDto;
}
