import { Injectable } from '@nestjs/common';
import { InjectModel } from '@nestjs/mongoose';
import { Model } from 'mongoose';
import { LogEntry, LogEntryDocument } from './models/logentry.model';

@Injectable()
export class LoggingService {
  constructor(
    @InjectModel('logging')
    private readonly logEntryModel: Model<LogEntryDocument>,
  ) {}

  private async addLogMessage(
    component: string,
    level: string,
    message: string,
  ): Promise<void> {
    await this.logEntryModel.create({
      component,
      level,
      timestamp: new Date().toUTCString(),
      message,
    });
  }

  async addDebugMessage(component: string, message: string): Promise<void> {
    await this.addLogMessage(component, 'DEBUG', message);
  }

  async addInfoMessage(component: string, message: string): Promise<void> {
    await this.addLogMessage(component, 'INFO', message);
  }

  async addWarningMessage(component: string, message: string): Promise<void> {
    await this.addLogMessage(component, 'WARNING', message);
  }

  async addErrorMessage(component: string, message: string): Promise<void> {
    await this.addLogMessage(component, 'ERROR', message);
  }

  async addCriticalMessage(component: string, message: string): Promise<void> {
    await this.addLogMessage(component, 'CRITICAL', message);
  }

  async deleteComponentMessages(component: string): Promise<void> {
    this.logEntryModel.deleteMany({ component });
  }

  async deleteAllMessages(): Promise<void> {
    this.logEntryModel.deleteMany({});
  }

  async componentMessages(component: string): Promise<LogEntry[]> {
    return this.logEntryModel.find({ component });
  }

  async allMessages(): Promise<LogEntry[]> {
    return this.logEntryModel.find({});
  }
}
